@@ -7,20 +7,23 @@ import tensorflow as tf
 from transformers_keras.adapters import parse_pretrained_model_files
 from transformers_keras.adapters.bert_adapter import BertAdapter
 
-from .modeling_utils import choose_activation, unpack_inputs_3
+from .modeling_utils import choose_activation
 
 
 class BertEmbedding(tf.keras.layers.Layer):
+    """Embedding layer."""
 
-    def __init__(self,
-                 vocab_size=21128,
-                 max_positions=512,
-                 embedding_size=768,
-                 type_vocab_size=2,
-                 hidden_dropout_rate=0.1,
-                 initializer_range=0.02,
-                 epsilon=1e-12,
-                 **kwargs):
+    def __init__(
+        self,
+        vocab_size=21128,
+        max_positions=512,
+        embedding_size=768,
+        type_vocab_size=2,
+        hidden_dropout_rate=0.1,
+        initializer_range=0.02,
+        epsilon=1e-12,
+        **kwargs
+    ):
         super().__init__(**kwargs)
         assert vocab_size > 0, "vocab_size must greater than 0."
         self.vocab_size = vocab_size
@@ -28,22 +31,22 @@ class BertEmbedding(tf.keras.layers.Layer):
         self.type_vocab_size = type_vocab_size
         self.embedding_size = embedding_size
         self.initializer_range = initializer_range
-        self.layernorm = tf.keras.layers.LayerNormalization(epsilon=epsilon, name='LayerNorm')
+        self.layernorm = tf.keras.layers.LayerNormalization(epsilon=epsilon, name="LayerNorm")
         self.dropout = tf.keras.layers.Dropout(hidden_dropout_rate)
 
     def build(self, input_shape):
         self.token_embedding = self.add_weight(
-            'word_embeddings',
+            "word_embeddings",
             shape=[self.vocab_size, self.embedding_size],
             initializer=tf.keras.initializers.TruncatedNormal(stddev=self.initializer_range),
         )
         self.position_embedding = self.add_weight(
-            'position_embeddings',
+            "position_embeddings",
             shape=[self.max_positions, self.embedding_size],
             initializer=tf.keras.initializers.TruncatedNormal(stddev=self.initializer_range),
         )
         self.token_type_embedding = self.add_weight(
-            'token_type_embeddings',
+            "token_type_embeddings",
             shape=[self.type_vocab_size, self.embedding_size],
             initializer=tf.keras.initializers.TruncatedNormal(stddev=self.initializer_range),
         )
@@ -72,29 +75,35 @@ class BertEmbedding(tf.keras.layers.Layer):
 
 
 class BertMultiHeadAtttetion(tf.keras.layers.Layer):
+    """Multi head attention."""
 
-    def __init__(self,
-                 hidden_size=768,
-                 num_attention_heads=8,
-                 attention_dropout_rate=0.1,
-                 initializer_range=0.02,
-                 epsilon=1e-8,
-                 **kwargs):
+    def __init__(
+        self,
+        hidden_size=768,
+        num_attention_heads=8,
+        attention_dropout_rate=0.1,
+        initializer_range=0.02,
+        epsilon=1e-8,
+        **kwargs
+    ):
         super().__init__(**kwargs)
         self.num_attention_heads = num_attention_heads
         self.hidden_size = hidden_size
         self.query_weight = tf.keras.layers.Dense(
             self.hidden_size,
             kernel_initializer=tf.keras.initializers.TruncatedNormal(stddev=initializer_range),
-            name='query')
+            name="query",
+        )
         self.key_weight = tf.keras.layers.Dense(
             self.hidden_size,
             kernel_initializer=tf.keras.initializers.TruncatedNormal(stddev=initializer_range),
-            name='key')
+            name="key",
+        )
         self.value_weight = tf.keras.layers.Dense(
             self.hidden_size,
             kernel_initializer=tf.keras.initializers.TruncatedNormal(stddev=initializer_range),
-            name='value')
+            name="value",
+        )
         self.attention_dropout = tf.keras.layers.Dropout(attention_dropout_rate)
 
     def _split_heads(self, x, batch_size):
@@ -122,28 +131,24 @@ class BertMultiHeadAtttetion(tf.keras.layers.Layer):
         query = self._split_heads(self.query_weight(query), batch_size)
         key = self._split_heads(self.key_weight(key), batch_size)
         value = self._split_heads(self.value_weight(value), batch_size)
-        context, attn_weights = self._scaled_dot_product_attention(
-            query, key, value, attention_mask, training=training)
+        context, attn_weights = self._scaled_dot_product_attention(query, key, value, attention_mask, training=training)
         context = tf.transpose(context, perm=[0, 2, 1, 3])
         context = tf.reshape(context, [batch_size, -1, self.hidden_size])
         return context, attn_weights
 
 
 class BertAttentionOutput(tf.keras.layers.Layer):
+    """Attention output layer."""
 
-    def __init__(self,
-                 hidden_size=768,
-                 hidden_dropout_rate=0.1,
-                 initializer_range=0.02,
-                 epsilon=1e-5,
-                 **kwargs):
+    def __init__(self, hidden_size=768, hidden_dropout_rate=0.1, initializer_range=0.02, epsilon=1e-5, **kwargs):
         super().__init__(**kwargs)
         self.dense = tf.keras.layers.Dense(
             hidden_size,
             kernel_initializer=tf.keras.initializers.TruncatedNormal(stddev=initializer_range),
-            name='dense')
+            name="dense",
+        )
         self.dropout = tf.keras.layers.Dropout(hidden_dropout_rate)
-        self.layernorm = tf.keras.layers.LayerNormalization(epsilon=epsilon, name='LayerNorm')
+        self.layernorm = tf.keras.layers.LayerNormalization(epsilon=epsilon, name="LayerNorm")
 
     def call(self, input_states, hidden_states, training=None):
         hidden_states = self.dense(hidden_states)
@@ -153,15 +158,18 @@ class BertAttentionOutput(tf.keras.layers.Layer):
 
 
 class BertAttention(tf.keras.layers.Layer):
+    """Bert attention."""
 
-    def __init__(self,
-                 hidden_size=768,
-                 num_attention_heads=8,
-                 hidden_dropout_rate=0.1,
-                 attention_dropout_rate=0.1,
-                 initializer_range=0.02,
-                 epsilon=1e-5,
-                 **kwargs):
+    def __init__(
+        self,
+        hidden_size=768,
+        num_attention_heads=8,
+        hidden_dropout_rate=0.1,
+        attention_dropout_rate=0.1,
+        initializer_range=0.02,
+        epsilon=1e-5,
+        **kwargs
+    ):
         super().__init__(**kwargs)
         self.attention = BertMultiHeadAtttetion(
             hidden_size=hidden_size,
@@ -169,29 +177,34 @@ class BertAttention(tf.keras.layers.Layer):
             attention_dropout_rate=attention_dropout_rate,
             initializer_range=initializer_range,
             epsilon=epsilon,
-            name='self')
+            name="self",
+        )
         self.attention_output = BertAttentionOutput(
             hidden_size=hidden_size,
             hidden_dropout_rate=hidden_dropout_rate,
             initializer_range=initializer_range,
             epsilon=epsilon,
-            name='output')
+            name="output",
+        )
 
     def call(self, hidden_states, attention_mask, training=None):
         context, attention_weights = self.attention(
-            hidden_states, hidden_states, hidden_states, attention_mask, training=training)
+            hidden_states, hidden_states, hidden_states, attention_mask, training=training
+        )
         outputs = self.attention_output(hidden_states, context, training=training)
         return outputs, attention_weights
 
 
 class BertIntermediate(tf.keras.layers.Layer):
+    """Bert intermediate."""
 
-    def __init__(self, intermediate_size=3072, activation='gelu', initializer_range=0.02, **kwargs):
+    def __init__(self, intermediate_size=3072, activation="gelu", initializer_range=0.02, **kwargs):
         super().__init__(**kwargs)
         self.dense = tf.keras.layers.Dense(
             intermediate_size,
             kernel_initializer=tf.keras.initializers.TruncatedNormal(stddev=initializer_range),
-            name='dense')
+            name="dense",
+        )
         self.activation = choose_activation(activation)
 
     def call(self, hidden_states):
@@ -201,15 +214,17 @@ class BertIntermediate(tf.keras.layers.Layer):
 
 
 class BertIntermediateOutput(tf.keras.layers.Layer):
+    """Bert intermediate output."""
 
     def __init__(self, hidden_size=768, hidden_dropout_rate=0.1, initializer_range=0.02, epsilon=1e-5, **kwargs):
         super().__init__(**kwargs)
         self.dense = tf.keras.layers.Dense(
             hidden_size,
             kernel_initializer=tf.keras.initializers.TruncatedNormal(stddev=initializer_range),
-            name='dense')
+            name="dense",
+        )
         self.dropout = tf.keras.layers.Dropout(hidden_dropout_rate)
-        self.layernorm = tf.keras.layers.LayerNormalization(epsilon=epsilon, name='LayerNorm')
+        self.layernorm = tf.keras.layers.LayerNormalization(epsilon=epsilon, name="LayerNorm")
 
     def call(self, input_states, hidden_states, training=None):
         hidden_states = self.dropout(self.dense(hidden_states), training=training)
@@ -218,17 +233,20 @@ class BertIntermediateOutput(tf.keras.layers.Layer):
 
 
 class BertEncoderLayer(tf.keras.layers.Layer):
+    """Encoder layer."""
 
-    def __init__(self,
-                 hidden_size=768,
-                 num_attention_heads=8,
-                 intermediate_size=3072,
-                 activation='gelu',
-                 hidden_dropout_rate=0.2,
-                 attention_dropout_rate=0.1,
-                 epsilon=1e-12,
-                 initializer_range=0.02,
-                 **kwargs):
+    def __init__(
+        self,
+        hidden_size=768,
+        num_attention_heads=8,
+        intermediate_size=3072,
+        activation="gelu",
+        hidden_dropout_rate=0.2,
+        attention_dropout_rate=0.1,
+        epsilon=1e-12,
+        initializer_range=0.02,
+        **kwargs
+    ):
         super().__init__(**kwargs)
         # attention block
         self.attention = BertAttention(
@@ -237,20 +255,23 @@ class BertEncoderLayer(tf.keras.layers.Layer):
             hidden_dropout_rate=hidden_dropout_rate,
             attention_dropout_rate=attention_dropout_rate,
             initializer_range=initializer_range,
-            name='attention')
+            name="attention",
+        )
         # intermediate block
         self.intermediate = BertIntermediate(
             intermediate_size=intermediate_size,
             activation=activation,
             initializer_range=initializer_range,
-            name='intermediate')
+            name="intermediate",
+        )
         # output block
         self.intermediate_output = BertIntermediateOutput(
             hidden_size=hidden_size,
             hidden_dropout_rate=hidden_dropout_rate,
             initializer_range=initializer_range,
             epsilon=epsilon,
-            name='output')
+            name="output",
+        )
 
     def call(self, hidden_states, attn_mask, training=None):
         attn_output, attn_weights = self.attention(hidden_states, attn_mask, training=training)
@@ -260,18 +281,21 @@ class BertEncoderLayer(tf.keras.layers.Layer):
 
 
 class BertEncoder(tf.keras.layers.Layer):
+    """Encoder."""
 
-    def __init__(self,
-                 num_layers=6,
-                 hidden_size=768,
-                 num_attention_heads=8,
-                 intermediate_size=3072,
-                 activation='gelu',
-                 hidden_dropout_rate=0.2,
-                 attention_dropout_rate=0.1,
-                 epsilon=1e-12,
-                 initializer_range=0.02,
-                 **kwargs):
+    def __init__(
+        self,
+        num_layers=6,
+        hidden_size=768,
+        num_attention_heads=8,
+        intermediate_size=3072,
+        activation="gelu",
+        hidden_dropout_rate=0.2,
+        attention_dropout_rate=0.1,
+        epsilon=1e-12,
+        initializer_range=0.02,
+        **kwargs
+    ):
         super().__init__(**kwargs)
         self.encoder_layers = [
             BertEncoderLayer(
@@ -283,8 +307,9 @@ class BertEncoder(tf.keras.layers.Layer):
                 attention_dropout_rate=attention_dropout_rate,
                 epsilon=epsilon,
                 initializer_range=initializer_range,
-                name='layer_{}'.format(i)
-            ) for i in range(num_layers)
+                name="layer_{}".format(i),
+            )
+            for i in range(num_layers)
         ]
 
     def call(self, hidden_states, attention_mask, training=None):
@@ -306,14 +331,16 @@ class BertEncoder(tf.keras.layers.Layer):
 
 
 class BertPooler(tf.keras.layers.Layer):
+    """Pooler."""
 
     def __init__(self, hidden_size=768, initializer_range=0.02, **kwargs):
         super().__init__(**kwargs)
         self.dense = tf.keras.layers.Dense(
             hidden_size,
             kernel_initializer=tf.keras.initializers.TruncatedNormal(stddev=initializer_range),
-            activation='tanh',
-            name='dense')
+            activation="tanh",
+            name="dense",
+        )
 
     def call(self, inputs):
         hidden_states = inputs
@@ -323,21 +350,24 @@ class BertPooler(tf.keras.layers.Layer):
 
 
 class BertModel(tf.keras.layers.Layer):
+    """Bert main model."""
 
-    def __init__(self,
-                 vocab_size=21128,
-                 max_positions=512,
-                 hidden_size=768,
-                 type_vocab_size=2,
-                 num_layers=6,
-                 num_attention_heads=8,
-                 intermediate_size=3072,
-                 activation='gelu',
-                 hidden_dropout_rate=0.2,
-                 attention_dropout_rate=0.1,
-                 initializer_range=0.02,
-                 epsilon=1e-12,
-                 **kwargs):
+    def __init__(
+        self,
+        vocab_size=21128,
+        max_positions=512,
+        hidden_size=768,
+        type_vocab_size=2,
+        num_layers=6,
+        num_attention_heads=8,
+        intermediate_size=3072,
+        activation="gelu",
+        hidden_dropout_rate=0.2,
+        attention_dropout_rate=0.1,
+        initializer_range=0.02,
+        epsilon=1e-12,
+        **kwargs
+    ):
         super().__init__(**kwargs)
         self.bert_embedding = BertEmbedding(
             vocab_size=vocab_size,
@@ -347,7 +377,8 @@ class BertModel(tf.keras.layers.Layer):
             hidden_dropout_rate=hidden_dropout_rate,
             initializer_range=initializer_range,
             epsilon=epsilon,
-            name='embeddings')
+            name="embeddings",
+        )
 
         self.bert_encoder = BertEncoder(
             num_layers=num_layers,
@@ -359,9 +390,10 @@ class BertModel(tf.keras.layers.Layer):
             attention_dropout_rate=attention_dropout_rate,
             epsilon=epsilon,
             initializer_range=initializer_range,
-            name='encoder')
+            name="encoder",
+        )
 
-        self.bert_pooler = BertPooler(hidden_size=hidden_size, initializer_range=initializer_range, name='pooler')
+        self.bert_pooler = BertPooler(hidden_size=hidden_size, initializer_range=initializer_range, name="pooler")
 
     def get_embedding_table(self):
         return self.bert_embedding.embedding_table
@@ -371,7 +403,8 @@ class BertModel(tf.keras.layers.Layer):
         # (batch_size, seq_len) -> (batch_size, 1, 1, seq_len)
         attention_mask = attention_mask[:, tf.newaxis, tf.newaxis, :]
         output, all_hidden_states, all_attention_scores = self.bert_encoder(
-            embedding, attention_mask, training=training)
+            embedding, attention_mask, training=training
+        )
         pooled_output = self.bert_pooler(output)
         return output, pooled_output, all_hidden_states, all_attention_scores
 
@@ -381,58 +414,77 @@ class BertPretrainedModel(tf.keras.Model):
 
     @classmethod
     def from_pretrained(
-            cls,
-            pretrained_model_dir,
-            model_params=None,
-            use_functional_api=True,
-            adapter=None,
-            check_weights=True,
-            verbose=True,
-            **kwargs):
+        cls,
+        pretrained_model_dir,
+        override_params=None,
+        use_functional_api=True,
+        adapter=None,
+        check_weights=True,
+        verbose=True,
+        **kwargs
+    ):
+        """Load pretrained bert weights.
+
+        Args:
+            pretrained_model_dir: A file path to pretrained model dir, including ckpt and config files.
+            override_params: Add extra model params or override pretrained model's params to constructor
+            use_functional_api: Python boolean, default is True.
+                When subclassing BertPretrainedModel, you may construct model using Keras' functional API,
+                then you should set use_functional_api=True, otherwise, you should set use_functional_api=False.
+            adapter: An adpater to adapte pretrained weights to this new created model. Default is `BertAdapter`.
+                In most case, you do not need to specify a `adapter`.
+            check_weights: Python boolean. If true, check model weights' value after loading weights from ckpt
+            verbose: Python boolean.If True, logging more detailed informations when loadding pretrained weights
+        """
+
         config_file, ckpt, _ = parse_pretrained_model_files(pretrained_model_dir)
         if not adapter:
             adapter = BertAdapter(
-                skip_token_embedding=kwargs.pop('skip_token_embedding', False),
-                skip_position_embedding=kwargs.pop('skip_position_embedding', False),
-                skip_segment_embedding=kwargs.pop('skip_segment_embedding', False),
-                skip_embedding_layernorm=kwargs.pop('skip_embedding_layernorm', False),
-                skip_pooler=kwargs.pop('skip_pooler', False),
-                verbose=kwargs.pop('verbose', False),
+                skip_token_embedding=kwargs.pop("skip_token_embedding", False),
+                skip_position_embedding=kwargs.pop("skip_position_embedding", False),
+                skip_segment_embedding=kwargs.pop("skip_segment_embedding", False),
+                skip_embedding_layernorm=kwargs.pop("skip_embedding_layernorm", False),
+                skip_pooler=kwargs.pop("skip_pooler", False),
             )
         model_config = adapter.adapte_config(config_file, **kwargs)
-        if model_params:
-            model_config.update(model_params)
-        logging.info('Load model config: \n%s', json.dumps(model_config, indent=4))
+        if override_params:
+            model_config.update(override_params)
+        logging.info("Load model config: \n%s", json.dumps(model_config, indent=4))
         model = cls(**model_config, **kwargs)
-        assert getattr(model, 'bert_model', None) is not None, 'BertPretrainedModel must have an attribute named bert_model!'
+        assert (
+            getattr(model, "bert_model", None) is not None
+        ), "BertPretrainedModel must have an attribute named bert_model!"
         inputs = model.dummy_inputs()
         model(inputs=list(inputs), training=False)
         adapter.adapte_weights(
             bert=model.bert_model,
             config=model_config,
             ckpt=ckpt,
-            prefix='' if use_functional_api else model.name,
+            prefix="" if use_functional_api else model.name,
             check_weights=check_weights,
             verbose=verbose,
-            **kwargs)
+            **kwargs
+        )
         return model
 
     @classmethod
-    def from_config_file(cls, config_file, model_params=None, adapter=None, **kwargs):
+    def from_config_file(cls, config_file, override_params=None, adapter=None, **kwargs):
         if not adapter:
             adapter = BertAdapter(
-                skip_token_embedding=kwargs.pop('skip_token_embedding', False),
-                skip_position_embedding=kwargs.pop('skip_position_embedding', False),
-                skip_segment_embedding=kwargs.pop('skip_segment_embedding', False),
-                skip_embedding_layernorm=kwargs.pop('skip_embedding_layernorm', False),
-                skip_pooler=kwargs.pop('skip_pooler', False)
+                skip_token_embedding=kwargs.pop("skip_token_embedding", False),
+                skip_position_embedding=kwargs.pop("skip_position_embedding", False),
+                skip_segment_embedding=kwargs.pop("skip_segment_embedding", False),
+                skip_embedding_layernorm=kwargs.pop("skip_embedding_layernorm", False),
+                skip_pooler=kwargs.pop("skip_pooler", False),
             )
         model_config = adapter.adapte_config(config_file, **kwargs)
-        if model_params:
-            model_config.update(model_params)
-        logging.info('Load model config: \n%s', json.dumps(model_config, indent=4))
+        if override_params:
+            model_config.update(override_params)
+        logging.info("Load model config: \n%s", json.dumps(model_config, indent=4))
         model = cls(**model_config, **kwargs)
-        assert getattr(model, 'bert_model', None) is not None, 'BertPretrainedModel must have an attribute named bert_model!'
+        assert (
+            getattr(model, "bert_model", None) is not None
+        ), "BertPretrainedModel must have an attribute named bert_model!"
         inputs = model.dummy_inputs()
         model(inputs=list(inputs), training=False)
         return model
@@ -445,26 +497,29 @@ class BertPretrainedModel(tf.keras.Model):
 
 
 class Bert(BertPretrainedModel):
+    """Bert, can load pretrained weights."""
 
-    def __init__(self,
-                 vocab_size=21128,
-                 max_positions=512,
-                 hidden_size=768,
-                 type_vocab_size=2,
-                 num_layers=6,
-                 num_attention_heads=8,
-                 intermediate_size=3072,
-                 activation='gelu',
-                 hidden_dropout_rate=0.2,
-                 attention_dropout_rate=0.1,
-                 initializer_range=0.02,
-                 epsilon=1e-12,
-                 return_states=False,
-                 return_attention_weights=False,
-                 **kwargs):
-        input_ids = tf.keras.layers.Input(shape=(None, ), dtype=tf.int32, name='input_ids')
-        segment_ids = tf.keras.layers.Input(shape=(None, ), dtype=tf.int32, name='segment_ids')
-        attention_mask = tf.keras.layers.Input(shape=(None, ), dtype=tf.int32, name='attention_mask')
+    def __init__(
+        self,
+        vocab_size=21128,
+        max_positions=512,
+        hidden_size=768,
+        type_vocab_size=2,
+        num_layers=6,
+        num_attention_heads=8,
+        intermediate_size=3072,
+        activation="gelu",
+        hidden_dropout_rate=0.2,
+        attention_dropout_rate=0.1,
+        initializer_range=0.02,
+        epsilon=1e-12,
+        return_states=False,
+        return_attention_weights=False,
+        **kwargs
+    ):
+        input_ids = tf.keras.layers.Input(shape=(None,), dtype=tf.int32, name="input_ids")
+        segment_ids = tf.keras.layers.Input(shape=(None,), dtype=tf.int32, name="segment_ids")
+        attention_mask = tf.keras.layers.Input(shape=(None,), dtype=tf.int32, name="attention_mask")
         bert_model = BertModel(
             vocab_size=vocab_size,
             max_positions=max_positions,
@@ -478,17 +533,19 @@ class Bert(BertPretrainedModel):
             attention_dropout_rate=attention_dropout_rate,
             initializer_range=initializer_range,
             epsilon=epsilon,
-            name='bert')
+            name="bert",
+        )
         sequence_output, pooled_output, hidden_states, attention_weights = bert_model(
-            input_ids, segment_ids, attention_mask)
+            input_ids, segment_ids, attention_mask
+        )
         outputs = [
-            tf.keras.layers.Lambda(lambda x: x, name='sequence_output')(sequence_output),
-            tf.keras.layers.Lambda(lambda x: x, name='pooled_output')(pooled_output),
+            tf.keras.layers.Lambda(lambda x: x, name="sequence_output")(sequence_output),
+            tf.keras.layers.Lambda(lambda x: x, name="pooled_output")(pooled_output),
         ]
         if return_states:
-            outputs += [tf.keras.layers.Lambda(lambda x: x, name='hidden_states')(hidden_states)]
+            outputs += [tf.keras.layers.Lambda(lambda x: x, name="hidden_states")(hidden_states)]
         if return_attention_weights:
-            outputs += [tf.keras.layers.Lambda(lambda x: x, name='attention_weights')(attention_weights)]
+            outputs += [tf.keras.layers.Lambda(lambda x: x, name="attention_weights")(attention_weights)]
 
         super().__init__(inputs=[input_ids, segment_ids, attention_mask], outputs=outputs, **kwargs)
 
@@ -509,17 +566,17 @@ class Bert(BertPretrainedModel):
 
     def get_config(self):
         config = {
-            'vocab_size': self.vocab_size,
-            'type_vocab_size': self.type_vocab_size,
-            'max_positions': self.max_positions,
-            'num_layers': self.num_layers,
-            'hidden_size': self.hidden_size,
-            'num_attention_heads': self.num_attention_heads,
-            'intermediate_size': self.intermediate_size,
-            'hidden_dropout_rate': self.hidden_dropout_rate,
-            'attention_dropout_rate': self.attention_dropout_rate,
-            'initializer_range': self.initializer_range,
-            'return_states': self.return_states,
-            'return_attention_weights': self.return_attention_weights,
+            "vocab_size": self.vocab_size,
+            "type_vocab_size": self.type_vocab_size,
+            "max_positions": self.max_positions,
+            "num_layers": self.num_layers,
+            "hidden_size": self.hidden_size,
+            "num_attention_heads": self.num_attention_heads,
+            "intermediate_size": self.intermediate_size,
+            "hidden_dropout_rate": self.hidden_dropout_rate,
+            "attention_dropout_rate": self.attention_dropout_rate,
+            "initializer_range": self.initializer_range,
+            "return_states": self.return_states,
+            "return_attention_weights": self.return_attention_weights,
         }
         return config
